@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.014-6-ge0c81aa
+package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.015-3-g33016d6
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Compare data and files at different phases of the distribution build process
 # KEYWORDS: plugin distribution configuration phase verification validation
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use Moose;
 with
@@ -14,7 +14,10 @@ with
     'Dist::Zilla::Role::EncodingProvider',
     'Dist::Zilla::Role::FilePruner',
     'Dist::Zilla::Role::FileMunger',
-    'Dist::Zilla::Role::AfterBuild';
+    'Dist::Zilla::Role::AfterBuild',
+    'Dist::Zilla::Role::BeforeRelease',
+    'Dist::Zilla::Role::Releaser',
+    'Dist::Zilla::Role::AfterRelease';
 use Moose::Util 'find_meta';
 use Digest::MD5 'md5_hex';
 use List::Util 1.33 qw(none any);
@@ -96,6 +99,8 @@ sub before_build
     # adjust plugin order so that we are always last!
     my $plugins = $self->zilla->plugins;
     @$plugins = ((grep { $_ != $self } @$plugins), $self);
+
+    $self->log_debug('---- this is the last before_build plugin ----');
 }
 
 sub gather_files
@@ -130,6 +135,8 @@ sub gather_files
             # content can change; don't bother capturing it yet
         };
     }
+
+    $self->log_debug('---- this is the last gather_files plugin ----');
 }
 
 # since last phase,
@@ -151,6 +158,8 @@ sub set_file_encodings
             $entry->{encoding} = $file->encoding if $entry->{object} eq $file;
         }
     }
+
+    $self->log_debug('---- this is the last set_file_encodings plugin ----');
 }
 
 # since last phase,
@@ -194,6 +203,8 @@ sub prune_files
             content => undef,   # content can change; don't bother capturing it yet
         };
     }
+
+    $self->log_debug('---- this is the last prune_files plugin ----');
 }
 
 my $distmeta;
@@ -267,6 +278,8 @@ sub munge_files
         );
         delete $distmeta->{prereqs};
     }
+
+    $self->log_debug('---- this is the last munge_files plugin ----');
 }
 
 # since last phase,
@@ -331,6 +344,27 @@ sub after_build
         chomp(my $error = deep_diag($stack));
         $self->_alert('distribution metadata has been altered after munging phase!', $error);
     }
+
+    $self->log_debug('---- this is the last after_build plugin ----');
+}
+
+sub before_release {
+    shift->log_debug('---- this is the last before_release plugin ----');
+}
+
+sub release
+{
+    my $self = shift;
+
+    # perform the check that we just neutered in Dist::Zilla::Dist::Builder::release
+    Carp::croak("you can't release without any Releaser plugins")
+        if @{ $self->zilla->plugins_with(-Releaser) } <= 1;
+
+    $self->log_debug('---- this is the last release plugin ----');
+}
+
+sub after_release {
+    shift->log_debug('---- this is the last after_release plugin ----');
 }
 
 sub _alert
@@ -353,7 +387,7 @@ Dist::Zilla::Plugin::VerifyPhases - Compare data and files at different phases o
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -436,6 +470,7 @@ before all content is available (for example, other lazy builders can run too
 early, resulting in incomplete or missing data).
 
 =for Pod::Coverage BUILD before_build gather_files set_file_encodings prune_files munge_files after_build
+before_release release after_release
 
 =head1 SEE ALSO
 
